==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fIfge.h <==
// class soot.coffi.Instruction_Ifge

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class b99958324f41fe71 soot_coffi_Instruction__5fIfge
// @dep_class f1ed2760eb94209e soot_coffi_Instruction__5fbranch
// @dep_class 6bcdce6545109d8e soot_coffi_Instruction__5fintbranch

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintbranch

#include "soot/coffi/Instruction__5fintbranch.h"

#ifndef _JC_soot_coffi_Instruction__5fIfge_H_
#define _JC_soot_coffi_Instruction__5fIfge_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIfge$sub_refs	_jc_soot_coffi_Instruction__5fIfge$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIfge$sub_nonrefs	_jc_soot_coffi_Instruction__5fIfge$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIfge$refs	_jc_soot_coffi_Instruction__5fIfge$refs;
typedef struct _jc_soot_coffi_Instruction__5fIfge$nonrefs	_jc_soot_coffi_Instruction__5fIfge$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIfge$object	_jc_soot_coffi_Instruction__5fIfge$object;

typedef const struct _jc_soot_coffi_Instruction__5fIfge$vmethods	_jc_soot_coffi_Instruction__5fIfge$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIfge$vtable	_jc_soot_coffi_Instruction__5fIfge$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIfge$vtype	_jc_soot_coffi_Instruction__5fIfge$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIfge$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIfge$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIfge$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIfge$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbranch$vmethods	soot_coffi_Instruction__5fbranch;
	_jc_soot_coffi_Instruction__5fintbranch$vmethods	soot_coffi_Instruction__5fintbranch;
	_jc_soot_coffi_Instruction__5fIfge$vmethods	soot_coffi_Instruction__5fIfge;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIfge$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIfge$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIfge$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIfge$refs {
    _jc_soot_coffi_Instruction__5fIfge$sub_refs	soot_coffi_Instruction__5fIfge;
    _jc_soot_coffi_Instruction__5fintbranch$sub_refs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fbranch$sub_refs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIfge$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIfge$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction__5fintbranch$sub_nonrefs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fIfge$sub_nonrefs	soot_coffi_Instruction__5fIfge;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIfge$object {
	_jc_soot_coffi_Instruction__5fIfge$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIfge$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIfge$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIfge$vtype _jc_soot_coffi_Instruction__5fIfge$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIfge, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIfge$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIfge_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fIfge.h <==
// class soot.coffi.Instruction_Ifge

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class b99958324f41fe71 soot_coffi_Instruction__5fIfge
// @dep_class f1ed2760eb94209e soot_coffi_Instruction__5fbranch
// @dep_class 6bcdce6545109d8e soot_coffi_Instruction__5fintbranch

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintbranch

#include "soot/coffi/Instruction__5fintbranch.h"

#ifndef _JC_soot_coffi_Instruction__5fIfge_H_
#define _JC_soot_coffi_Instruction__5fIfge_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIfge$sub_refs	_jc_soot_coffi_Instruction__5fIfge$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIfge$sub_nonrefs	_jc_soot_coffi_Instruction__5fIfge$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIfge$refs	_jc_soot_coffi_Instruction__5fIfge$refs;
typedef struct _jc_soot_coffi_Instruction__5fIfge$nonrefs	_jc_soot_coffi_Instruction__5fIfge$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIfge$object	_jc_soot_coffi_Instruction__5fIfge$object;

typedef const struct _jc_soot_coffi_Instruction__5fIfge$vmethods	_jc_soot_coffi_Instruction__5fIfge$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIfge$vtable	_jc_soot_coffi_Instruction__5fIfge$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIfge$vtype	_jc_soot_coffi_Instruction__5fIfge$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIfge$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIfge$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIfge$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIfge$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbranch$vmethods	soot_coffi_Instruction__5fbranch;
	_jc_soot_coffi_Instruction__5fintbranch$vmethods	soot_coffi_Instruction__5fintbranch;
	_jc_soot_coffi_Instruction__5fIfge$vmethods	soot_coffi_Instruction__5fIfge;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIfge$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIfge$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIfge$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIfge$refs {
    _jc_soot_coffi_Instruction__5fIfge$sub_refs	soot_coffi_Instruction__5fIfge;
    _jc_soot_coffi_Instruction__5fintbranch$sub_refs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fbranch$sub_refs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIfge$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIfge$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction__5fintbranch$sub_nonrefs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fIfge$sub_nonrefs	soot_coffi_Instruction__5fIfge;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIfge$object {
	_jc_soot_coffi_Instruction__5fIfge$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIfge$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIfge$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIfge$vtype _jc_soot_coffi_Instruction__5fIfge$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIfge, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIfge$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIfge_H_ */
